<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Service;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class ServiceController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.service', [
            'services' => Service::get(),
        ]);
    }

    public function service_add()
    {
        return view('admin.service_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'photo' => 'required|file|image',
            'banner' => 'required|file|image',
            'heading' => 'required|unique:services',
            'slug' => 'unique:services',
            'short_content' => 'required',
            'full_content' => 'required',
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->heading);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = Service::where('slug', $slug)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'service_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        if ($request->hasFile('banner')) {
            $file = $request->file('banner');
            $ext = $file->getClientOriginalExtension();
            $filename2 = 'service_banner_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename2);
        }

        Service::create([
            'heading' => $request->heading,
            'slug' => $slug,
            'short_content' => $request->short_content,
            'full_content' => $request->full_content,
            'photo' => $filename1,
            'banner' => $filename2,
            'meta_title' => $request->meta_title,
            'meta_description' => $request->meta_description
        ]);

        return Redirect()->route('admin.service')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.service_edit', [
            'service' => Service::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'heading' => ['required',Rule::unique('services')->ignore($id),],
            'slug' => [Rule::unique('services')->ignore($id),],
            'short_content' => 'required',
            'full_content' => 'required',
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->heading);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = Service::where('slug', $slug)->where('id', '!=', $id)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        $service = Service::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$service->photo));
            $filename1 = 'service_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $service->photo = $filename1;
        }

        if ($request->hasFile('banner')) {
            $request->validate([
                'banner' => 'image'
            ]);
            $file = $request->file('banner');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$service->banner));
            $filename2 = 'service_banner_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename2);
            $service->banner = $filename2;
        }

        $service->heading          = $request->heading;
        $service->slug             = $slug;
        $service->short_content    = $request->short_content;
        $service->full_content     = $request->full_content;
        $service->meta_title       = $request->meta_title;
        $service->meta_description = $request->meta_description;
        $service->update();

        return Redirect()->route('admin.service')->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = Service::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        $banner = Service::find($id)->banner;
        unlink(public_path('uploads/' . $banner));
        Service::find($id)->forceDelete();
        return Redirect()->route('admin.service')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
