<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Designation;
use App\Models\Team;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Image;

class TeamController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.team', [
            'teams' => Team::get(),
        ]);
    }

    public function team_add()
    {
        return view('admin.team_add', [
            'designations' => Designation::all(),
        ]);
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'name' => 'required',
            'photo' => 'required|file|image',
            'designation_id' => 'required',
        ]);

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'team_member_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        Team::create([
            'name' => $request->name,
            'photo' => $filename1,
            'designation_id' => $request->designation_id,
            'facebook' => $request->facebook,
            'twitter' => $request->twitter,
            'linkedin' => $request->linkedin,
            'youtube' => $request->youtube,
            'google_plus' => $request->google_plus,
            'instagram' => $request->instagram,
            'flickr' => $request->flickr,
        ]);

        return Redirect()->route('admin.team')->with('success', A_SUCCESS_DATA_ADD);

    }


    public function edit_page($id)
    {
        return view('admin.team_edit', [
            'team' => Team::find($id),
            'designations' => Designation::all(),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'name' => 'required',
            'designation_id' => 'required'
        ]);

        $team = Team::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$team->photo));
            $filename1 = 'team_member_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $team->photo = $filename1;
        }

        $team->name = $request->name;
        $team->designation_id = $request->designation_id;
        $team->facebook = $request->facebook;
        $team->twitter = $request->twitter;
        $team->linkedin = $request->linkedin;
        $team->youtube = $request->youtube;
        $team->google_plus = $request->google_plus;
        $team->instagram = $request->instagram;
        $team->flickr = $request->flickr;
        $team->update();

        return Redirect()->route('admin.team')->with('success', A_SUCCESS_DATA_UPDATE);

    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = Team::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        Team::find($id)->forceDelete();
        return Redirect()->route('admin.team')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
